==> bonita-server-6.1.2-sources.jar: org/bonitasoft/engine/core/process/definition/model/builder/event/trigger/impl/SThrowErrorEventTriggerDefinitionBuilderImpl.java <==
/**
 * Copyright (C) 2013 BonitaSoft S.A.
 * BonitaSoft, 32 rue Gustave Eiffel - 38000 Grenoble
 * This library is free software; you can redistribute it and/or modify it under the terms
 * of the GNU Lesser General Public License as published by the Free Software Foundation
 * version 2.1 of the License.
 * This library is distributed in the hope that it will be useful, but WITHOUT ANY WARRANTY;
 * without even the implied warranty of MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.
 * See the GNU Lesser General Public License for more details.
 * You should have received a copy of the GNU Lesser General Public License along with this
 * program; if not, write to the Free Software Foundation, Inc., 51 Franklin Street, Fifth
 * Floor, Boston, MA 02110-1301, USA.
 **/
package org.bonitasoft.engine.core.process.definition.model.builder.event.trigger.impl;

import org.bonitasoft.engine.core.process.definition.model.builder.event.trigger.SThrowErrorEventTriggerDefinitionBuilder;
import org.bonitasoft.engine.core.process.definition.model.event.trigger.SThrowErrorEventTriggerDefinition;
import org.bonitasoft.engine.core.process.definition.model.event.trigger.impl.SThrowErrorEventTriggerDefinitionImpl;

/**
 * @author Baptiste Mesta
 */
public class SThrowErrorEventTriggerDefinitionBuilderImpl implements SThrowErrorEventTriggerDefinitionBuilder {

    private SThrowErrorEventTriggerDefinition entity = null;

    @Override
    public SThrowErrorEventTriggerDefinition done() {
        return entity;
    }

    @Override
    public SThrowErrorEventTriggerDefinitionBuilder createNewInstance(final String errorCode) {
        entity = new SThrowErrorEventTriggerDefinitionImpl(errorCode);
        return this;
    }
}

==> bonita-server-6.5.0-sources.jar: org/bonitasoft/engine/core/process/definition/model/builder/event/trigger/impl/SThrowErrorEventTriggerDefinitionBuilderImpl.java <==
/**
 * Copyright (C) 2013 BonitaSoft S.A.
 * BonitaSoft, 32 rue Gustave Eiffel - 38000 Grenoble
 * This library is free software; you can redistribute it and/or modify it under the terms
 * of the GNU Lesser General Public License as published by the Free Software Foundation
 * version 2.1 of the License.
 * This library is distributed in the hope that it will be useful, but WITHOUT ANY WARRANTY;
 * without even the implied warranty of MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.
 * See the GNU Lesser General Public License for more details.
 * You should have received a copy of the GNU Lesser General Public License along with this
 * program; if not, write to the Free Software Foundation, Inc., 51 Franklin Street, Fifth
 * Floor, Boston, MA 02110-1301, USA.
 **/
package org.bonitasoft.engine.core.process.definition.model.builder.event.trigger.impl;

import org.bonitasoft.engine.core.process.definition.model.builder.event.trigger.SThrowErrorEventTriggerDefinitionBuilder;
import org.bonitasoft.engine.core.process.definition.model.event.trigger.SThrowErrorEventTriggerDefinition;

/**
 * @author Baptiste Mesta
 */
public class SThrowErrorEventTriggerDefinitionBuilderImpl implements SThrowErrorEventTriggerDefinitionBuilder {

    private final SThrowErrorEventTriggerDefinition entity;

    public SThrowErrorEventTriggerDefinitionBuilderImpl(final SThrowErrorEventTriggerDefinition entity) {
        super();
        this.entity = entity;
    }

    @Override
    public SThrowErrorEventTriggerDefinition done() {
        return entity;
    }

}
